# SecureAgentStatus

Status information pertaining to the secure agent
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**application_services** | [**list[ApplicationService]**](ApplicationService.md) | The list of application services associated with this secure agent | [optional] 
**connector_info** | [**list[SecureAgentConnectorInfo]**](SecureAgentConnectorInfo.md) | Each item in this list informs the agent of how to connect to a connector in the agilicus infrastructure.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


